@@ -2,6 +2,7 @@ from __future__ import absolute_import, print_function
 
 import getpass
 import jinja2
+import logging
 import os
 import pandas as pd
 import random
@@ -12,7 +13,6 @@ import traceback
 from builtins import map, str
 from contextlib import closing
 from logging import ERROR as LOG_ERROR
-from logging import getLogger
 from threading import Timer
 
 from flask import Flask, jsonify, redirect, render_template, request, url_for
@@ -45,7 +45,7 @@ if PY3:
 else:
     import thread as _thread
 
-logger = getLogger(__name__)
+logger = logging.getLogger(__name__)
 
 USE_NGROK = False
 USE_COLAB = False
@@ -53,7 +53,15 @@ JUPYTER_SERVER_PROXY = False
 ACTIVE_HOST = None
 ACTIVE_PORT = None
 
-SHORT_LIFE_PATHS = ["dist", "dash"]
+_basepath = os.path.dirname(__file__)
+_filepath = os.path.abspath(os.path.join(_basepath, "static"))
+
+SHORT_LIFE_PATHS = [
+    "dist",
+    os.path.join(_filepath, "dist"),
+    "dash",
+    os.path.join(_filepath, "dash"),
+]
 SHORT_LIFE_TIMEOUT = 60
 
 REAPER_TIMEOUT = 60.0 * 60.0  # one-hour
@@ -248,7 +256,7 @@ class DtaleFlask(Flask):
                  otherwise SHORT_LIFE_TIMEOUT
 
         """
-        if name and any([name.startswith(path) for path in SHORT_LIFE_PATHS]):
+        if name and any([str(name).startswith(path) for path in SHORT_LIFE_PATHS]):
             return SHORT_LIFE_TIMEOUT
         return super(DtaleFlask, self).get_send_file_max_age(name)
 
@@ -680,6 +688,7 @@ def show(data=None, data_loader=None, name=None, context_vars=None, **options):
             precision=final_options["precision"],
             show_columns=final_options["show_columns"],
             hide_columns=final_options["hide_columns"],
+            column_formats=final_options["column_formats"],
         )
         instance.started_with_open_browser = final_options["open_browser"]
         is_active = not running_with_flask_debug() and is_up(app_url)
@@ -706,7 +715,7 @@ def show(data=None, data_loader=None, name=None, context_vars=None, **options):
                     app.jinja_env.auto_reload = True
                     app.config["TEMPLATES_AUTO_RELOAD"] = True
                 else:
-                    getLogger("werkzeug").setLevel(LOG_ERROR)
+                    logging.getLogger("werkzeug").setLevel(LOG_ERROR)
 
                 if final_options["open_browser"]:
                     instance.open_browser()
@@ -735,7 +744,8 @@ def show(data=None, data_loader=None, name=None, context_vars=None, **options):
             if final_options["notebook"]:
                 instance.notebook()
         else:
-            logger.info("D-Tale started at: {}".format(app_url))
+            # Need to use logging.info() because for some reason other libraries like arctic seem to break logging
+            logging.info("D-Tale started at: {}".format(app_url))
             _start()
 
         return instance
