@@ -3,6 +3,7 @@ import copy
 import numpy as np
 import pandas as pd
 
+import dtale.global_state as global_state
 from dtale.column_analysis import handle_cleaners
 from dtale.query import build_col_key, run_query
 from dtale.utils import (
@@ -44,9 +45,22 @@ AGGS = dict(
     var="Variance",
     mad="Mean Absolute Deviation",
     prod="Product of All Items",
-    pctct="Percentage Count",
+    pctct="Count (Percentage)",
     pctsum="Percentage Sum",
 )
+INDEX_COL = "__index__"
+
+CHART_POINTS_LIMIT = (
+    "In order to adjust the limitation on the amount of points in charts please update your startup code that "
+    "loads the dataframe to D-Tale and add these lines of code before calling 'dtale.show':\n\n"
+    "import dtale.global_state as global_state\n\n"
+    "global_state.set_chart_settings({'scatter_points': 15000, '3d_points': 40000})\n\n"
+    "You could also add the following properties to your global configuration file:\n\n"
+    "[charts]\n"
+    "scatter_points = 20000\n\n"
+    "Documentation on global configurations can be found here:\n"
+    "https://github.com/man-group/dtale/blob/master/docs/CONFIGURATION.md"
+)
 
 
 def get_mapbox_token():
@@ -319,6 +333,14 @@ def retrieve_chart_data(df, *args, **kwargs):
     cols = flatten_lists([make_list(a) for a in args])
     all_code = []
     all_data = []
+
+    if INDEX_COL in cols:
+        cols = [col for col in cols if col != INDEX_COL]
+        all_data.append(pd.Series(df.index, index=df.index, name="__index__"))
+        all_code.append(
+            "\tpd.Series(df.index, index=df.index, name='{}'),".format(INDEX_COL)
+        )
+
     for col in cols:
         if col is not None:
             s, code = freq_handler(col)
@@ -560,6 +582,10 @@ def compute_aggs(df, groups, aggs, idx_cols, group_col):
                 / getattr(df.groupby(subidx_cols)[curr_agg_cols], func)()
                 * 100
             )
+            if isinstance(calc_group, pd.Series):
+                calc_group.name = curr_agg_cols[0]
+                calc_group = calc_group.to_frame()
+
             if len(curr_agg_cols) > 1:
                 groups.columns = curr_agg_cols
             elif len(curr_agg_cols) == 1:
@@ -898,11 +924,14 @@ def build_base_chart(
     code.append("chart_data = chart_data.dropna()")
 
     dupe_cols = main_group + y_group_cols
+    data_limit = global_state.get_chart_settings()[
+        "3d_points" if is_z or animate_by is not None else "scatter_points"
+    ]
     check_exceptions(
         data[dupe_cols].rename(columns={x_col: x}),
         allow_duplicates or agg in ["raw", "drop_duplicates"],
         unlimited_data=unlimited_data,
-        data_limit=40000 if is_z or animate_by is not None else 15000,
+        data_limit=data_limit,
     )
     data_f, range_f = build_formatters(data)
 
