@@ -45,7 +45,7 @@ def find_loader(kwargs):
     :param kwargs: Optional keyword arguments to be passed from `click`
     :return: data loader function for Parquet implementation
     """
-    parquet_opts = get_loader_options(LOADER_KEY, kwargs)
+    parquet_opts = get_loader_options(LOADER_KEY, LOADER_PROPS, kwargs)
     if len([f for f in parquet_opts.values() if f]):
 
         def _parquet_loader():
