@@ -45,12 +45,27 @@ def validate_allow_cell_edits(ctx, param, value):
     is_flag=True,
     help='flag to show "Fork Me On GitHub" link in upper right-hand corner of the app',
 )
+@click.option("--app-root", type=str)
 @click.option(
     "--theme",
     default="light",
     type=click.Choice(["light", "dark"]),
     help='theme you would like used for D-Tale, the default is "light"',
 )
+@click.option(
+    "--precision",
+    default=2,
+    type=int,
+    help="Default precision displayed by columns containing float data (default: 2)",
+)
+@click.option(
+    "--show-columns",
+    help="Comma-separated string of column names you would like displayed on load",
+)
+@click.option(
+    "--hide-columns",
+    help="Comma-separated string of column names you would like hidden on load",
+)
 @setup_loader_options()
 @click.option("--log", "logfile", help="Log file name")
 @click.option(
@@ -71,6 +86,7 @@ def main(
     no_cell_edits=None,
     hide_shutdown=None,
     github_fork=None,
+    app_root=None,
     **kwargs
 ):
     """
@@ -89,6 +105,12 @@ def main(
     # in order to handle the hierarchy of inputs if "--no-cell-edits" is not specified
     # then we'll update it to None
     allow_cell_edits = False if no_cell_edits is not None else None
+    kwargs["show_columns"] = (
+        kwargs["show_columns"].split(",") if kwargs.get("show_columns") else None
+    )
+    kwargs["hide_columns"] = (
+        kwargs["hide_columns"].split(",") if kwargs.get("hide_columns") else None
+    )
     show(
         host=host,
         port=int(port or find_free_port()),
@@ -101,6 +123,7 @@ def main(
         allow_cell_edits=allow_cell_edits,
         hide_shutdown=hide_shutdown,
         github_fork=github_fork,
+        app_root=app_root,
         **kwargs
     )
 
