@@ -7,14 +7,15 @@ import scipy.stats as sts
 
 import dtale.global_state as global_state
 
-from dtale.code_export import build_code_export, CHART_EXPORT_CODE
+from dtale.code_export import build_code_export, build_final_chart_code
 from dtale.column_builders import clean, clean_code
 from dtale.describe import load_describe
-from dtale.query import build_query, run_query
+from dtale.query import build_query, handle_predefined, run_query
 from dtale.utils import (
     apply,
     classify_type,
     find_dtype,
+    find_dtype_formatter,
     find_selected_column,
     get_int_arg,
     get_str_arg,
@@ -82,7 +83,7 @@ class ColumnAnalysis(object):
         self.query = build_query(data_id, curr_settings.get("query"))
 
         data = run_query(
-            global_state.get_data(self.data_id),
+            handle_predefined(data_id),
             self.query,
             global_state.get_context_variables(self.data_id),
         )
@@ -138,7 +139,7 @@ class ColumnAnalysis(object):
         )
         return_data, code = self.analysis.build(self)
         return dict(
-            code="\n".join(base_code + code + [CHART_EXPORT_CODE]),
+            code=build_final_chart_code(base_code + code),
             query=self.query,
             cols=global_state.get_dtypes(self.data_id),
             dtype=self.dtype,
@@ -150,27 +151,57 @@ class ColumnAnalysis(object):
 class HistogramAnalysis(object):
     def __init__(self, req):
         self.bins = get_int_arg(req, "bins", 20)
+        self.target = get_str_arg(req, "target")
+
+    def build_histogram_data(self, series):
+        hist_data, hist_labels = np.histogram(series, bins=self.bins)
+        hist_data = [json_float(h) for h in hist_data]
+        return (
+            dict(
+                labels=[
+                    "{0:.1f}".format(lbl) for lbl in hist_labels[1:]
+                ],  # drop the first bin because of just a minimum
+                data=hist_data,
+            ),
+            hist_labels,
+        )
 
     def build(self, parent):
         if parent.classifier == "D":
             parent.data.loc[:, parent.selected_col] = apply(
                 parent.data[parent.selected_col], json_timestamp
             )
-        hist_data, hist_labels = np.histogram(
-            parent.data[parent.selected_col], bins=self.bins
-        )
-        hist_data = [json_float(h) for h in hist_data]
-        return_data = dict(
-            labels=[
-                "{0:.1f}".format(lbl) for lbl in hist_labels[1:]
-            ],  # drop the first bin because of just a minimum
-            data=hist_data,
-        )
-        kde, kde_code = build_kde(
-            parent.data[parent.selected_col], hist_labels, parent.selected_col
-        )
-        if kde is not None:
-            return_data["kde"] = kde
+        kde_code = []
+        if self.target is None:
+            return_data, hist_labels = self.build_histogram_data(
+                parent.data[parent.selected_col]
+            )
+            kde, kde_code = build_kde(
+                parent.data[parent.selected_col], hist_labels, parent.selected_col
+            )
+            if kde is not None:
+                return_data["kde"] = kde
+        else:
+            bin_vals = pd.cut(parent.data[parent.selected_col], bins=self.bins)
+            labels = ["{}".format(c) for c in bin_vals.dtype.categories]
+            parent.data.loc[:, "bin"] = bin_vals.astype("str")
+            return_data = {"targets": [], "labels": labels}
+            target_dtype = find_dtype(parent.data[self.target])
+            target_formatter = find_dtype_formatter(target_dtype)
+            for target, target_data in parent.data[[self.target, "bin"]].groupby(
+                self.target
+            ):
+                target_counts = target_data["bin"].value_counts()
+                target_counts = [
+                    int(tc) for tc in target_counts.reindex(labels, fill_value=0).values
+                ]
+                return_data["targets"].append(
+                    dict(
+                        target=target_formatter(target, as_string=True),
+                        data=target_counts,
+                    )
+                )
+
         desc, desc_code = load_describe(parent.data[parent.selected_col])
         dtype_info = global_state.get_dtype_info(parent.data_id, parent.selected_col)
         for p in ["skew", "kurt"]:
@@ -182,29 +213,12 @@ class HistogramAnalysis(object):
 
     def _build_code(self, parent, kde_code, desc_code):
         pp = pprint.PrettyPrinter(indent=4)
-        layout = pp.pformat(
-            go.Layout(
-                **{
-                    "barmode": "group",
-                    "legend": {"orientation": "h"},
-                    "title": {
-                        "text": "{} Histogram (bins: {}) w/ KDE".format(
-                            parent.selected_col, self.bins
-                        )
-                    },
-                    "xaxis2": {"anchor": "y", "overlaying": "x", "side": "top"},
-                    "yaxis": {"title": {"text": "Frequency"}, "side": "left"},
-                    "yaxis2": {
-                        "title": {"text": "KDE"},
-                        "side": "right",
-                        "overlaying": "y",
-                    },
-                }
-            )
-        )
 
         code = [
-            "s = df[~pd.isnull(df['{col}'])][['{col}']]".format(col=parent.selected_col)
+            "s = df[~pd.isnull(df['{col}'])][['{col}'{target}]]".format(
+                col=parent.selected_col,
+                target=",'{}'".format(self.target) if self.target else "",
+            )
         ]
         if parent.classifier == "D":
             code.append(
@@ -215,21 +229,72 @@ class HistogramAnalysis(object):
                     ")"
                 ).format(col=parent.selected_col)
             )
+        if self.target is None:
+            code.append(
+                "chart, labels = np.histogram(s['{col}'], bins={bins})".format(
+                    col=parent.selected_col, bins=self.bins
+                )
+            )
+            code += kde_code + desc_code
+            layout = pp.pformat(
+                go.Layout(
+                    **{
+                        "barmode": "group",
+                        "legend": {"orientation": "h"},
+                        "title": {
+                            "text": "{} Histogram (bins: {}) w/ KDE".format(
+                                parent.selected_col, self.bins
+                            )
+                        },
+                        "xaxis2": {"anchor": "y", "overlaying": "x", "side": "top"},
+                        "yaxis": {"title": {"text": "Frequency"}, "side": "left"},
+                        "yaxis2": {
+                            "title": {"text": "KDE"},
+                            "side": "right",
+                            "overlaying": "y",
+                        },
+                    }
+                )
+            )
+            code += [
+                "charts = [",
+                "\tgo.Bar(x=labels[1:], y=chart, name='Histogram'),",
+                "\tgo.Scatter(",
+                "\t\tx=list(range(len(kde_data))), y=kde_data, name='KDE',"
+                "\t\tyaxis='y2', xaxis='x2',"
+                "\t\t{}".format(LINE_CFG),
+                "\t)",
+                "]",
+            ]
+        else:
+            layout = pp.pformat(
+                go.Layout(
+                    **{
+                        "barmode": "stack",
+                        "legend": {"orientation": "h"},
+                        "title": {
+                            "text": "{} Histogram (bins: {}) w/ target ({})".format(
+                                parent.selected_col, self.bins, self.target
+                            )
+                        },
+                        "yaxis": {"title": {"text": "Frequency"}, "side": "left"},
+                    }
+                )
+            )
+            code.append(
+                (
+                    "bin_vals = pd.cut(s['{col}'], bins={bins})\n"
+                    "labels = [str(c) for c in bin_vals.dtype.categories]\n"
+                    "s.loc[:, 'bin'] = bin_vals.astype('str')\n"
+                    "for target, target_data in s[['{target}', 'bin']].groupby('{target}'):\n"
+                    "\ttarget_counts = target_data['bin'].value_counts()\n"
+                    "\ttarget_counts = [int(tc) for tc in target_counts.reindex(labels, fill_value=0).values]\n"
+                    "\tcharts.append(go.Bar(x=labels, y=target_counts, name=target))"
+                ).format(col=parent.selected_col, bins=self.bins, target=self.target)
+            )
         code.append(
-            "chart, labels = np.histogram(s, bins={bins})".format(bins=self.bins)
+            "figure = go.Figure(data=charts, layout=go.{layout})".format(layout=layout)
         )
-        code += kde_code + desc_code
-        code += [
-            "charts = [",
-            "\tgo.Bar(x=labels[1:], y=chart, name='Histogram'),",
-            "\tgo.Scatter(",
-            "\t\tx=list(range(len(kde_data))), y=kde_data, name='KDE',"
-            "\t\tyaxis='y2', xaxis='x2',"
-            "\t\t{}".format(LINE_CFG),
-            "\t)",
-            "]",
-            "figure = go.Figure(data=charts, layout=go.{layout})".format(layout=layout),
-        ]
         return code
 
 
