@@ -34,7 +34,7 @@ from dtale.dash_application.layout.utils import (
     FREQ_LABELS,
 )
 from dtale.translations import text
-from dtale.query import build_query, inner_build_query, run_query
+from dtale.query import build_query, handle_predefined, inner_build_query, run_query
 from dtale.utils import (
     ChartBuildingError,
     classify_type,
@@ -87,7 +87,7 @@ def base_layout(app_root, **kwargs):
         )
     language = global_state.get_app_settings()["language"]
     language_links = []
-    for value, label in [("en", "English"), ("cn", "Chinese")]:
+    for value, label in [("en", "English"), ("cn", "Chinese"), ("pt", "Portuguese")]:
         if value == language:
             language_links.append(
                 """<span class="dropdown-item active">{}</span>""".format(
@@ -101,19 +101,31 @@ def base_layout(app_root, **kwargs):
                 )
             )
 
+    main_title = global_state.get_app_settings().get("main_title") or "D-TALE"
+    main_title_font = global_state.get_app_settings().get("main_title_font")
+    main_title_class = "title-font-base"
+    main_title_style = ""
+    if main_title_font:
+        main_title_style = "font-family: {main_title_font}".format(
+            main_title_font=main_title_font
+        )
+    else:
+        main_title_class = "title-font title-font-base"
+    page_title = global_state.get_app_settings().get("main_title") or "D-Tale"
+
     return """
         <!DOCTYPE html>
         <html>
             <head>
                 {webroot_html}
                 {metas}
-                <title>D-Tale Charts</title>
+                <title>{page_title} Charts</title>
                 <link rel="shortcut icon" href="{favicon_path}">
                 {css}
             </head>
-            <body>
+            <body class="{theme}-mode">
                 <header class="app-header">
-                    <span class="title-font">D-TALE</span>
+                    <span class="{main_title_class}" style="{main_title_style}">{main_title}</span>
                     <span style="font-size: 16px" class="pl-5 mt-4">{title}</span>
                     <nav class="app-header__nav--secondary">
                         <ul class="nav-menus">
@@ -167,6 +179,11 @@ def base_layout(app_root, **kwargs):
         grid_links="".join(grid_links),
         languages=text("Languages"),
         language_links="".join(language_links),
+        main_title=main_title,
+        main_title_class=main_title_class,
+        main_title_style=main_title_style,
+        page_title=page_title,
+        theme=global_state.get_app_settings()["theme"],
     )
 
 
@@ -1096,7 +1113,7 @@ def main_inputs_and_group_val_display(inputs):
 def build_slider_counts(df, data_id, query_value):
     record_ct = len(
         run_query(
-            df,
+            handle_predefined(data_id, df=df),
             build_query(data_id, query_value),
             global_state.get_context_variables(data_id),
         )
@@ -1788,6 +1805,7 @@ def charts_layout(df, settings, **inputs):
                                                     build_option(v, text(AGGS[v]))
                                                     for v in [
                                                         "count",
+                                                        "pctct",
                                                         "nunique",
                                                         "sum",
                                                         "mean",
@@ -1804,7 +1822,6 @@ def charts_layout(df, settings, **inputs):
                                                         "mad",
                                                         "prod",
                                                         "pctsum",
-                                                        "pctct",
                                                     ]
                                                 ],
                                                 placeholder=text("No Aggregation"),
