@@ -19,7 +19,7 @@ from dtale.charts.utils import (
     NON_EXT_AGGREGATION,
     build_final_cols,
 )
-from dtale.code_export import CHART_EXPORT_CODE
+from dtale.code_export import build_final_chart_code
 from dtale.dash_application.charts import (
     build_chart,
     chart_url_params,
@@ -53,7 +53,7 @@ from dtale.dash_application.layout.layout import (
 from dtale.dash_application.layout.utils import show_style
 from dtale.dash_application.utils import get_data_id
 from dtale.translations import text
-from dtale.query import run_query
+from dtale.query import handle_predefined, run_query
 from dtale.utils import dict_merge, is_app_root_defined, make_list
 
 logger = getLogger(__name__)
@@ -173,7 +173,7 @@ def init_callbacks(dash_app):
         :rtype: tuple of (str, str, str)
         """
         try:
-            data = global_state.get_data(data_id)
+            data = handle_predefined(data_id)
             ctxt_vars = global_state.get_context_variables(data_id)
             df = run_query(data, query, ctxt_vars)
             return (
@@ -868,7 +868,7 @@ def init_callbacks(dash_app):
             charts,
             all_inputs,
             range_data,
-            "\n".join(make_list(code) + [CHART_EXPORT_CODE]),
+            build_final_chart_code(code),
             get_yaxis_type_tabs(final_cols),
             load_clicks,
             dict(display="block" if valid_chart(**all_inputs) else "none"),
@@ -1105,7 +1105,7 @@ def init_callbacks(dash_app):
         if "groups" not in group_types:
             return [], None
         group_vals = run_query(
-            global_state.get_data(data_id),
+            handle_predefined(data_id),
             inputs.get("query"),
             global_state.get_context_variables(data_id),
         )
