@@ -22,7 +22,10 @@ def inner_build_query(settings, query=None):
             query_segs.append(filter_cfg["query"])
     if query not in [None, ""]:
         query_segs.append(query)
-    return " and ".join(query_segs)
+    joined_query_segs = " and ".join(query_segs)
+    if joined_query_segs and settings.get("invertFilter", False):
+        joined_query_segs = "~({})".format(joined_query_segs)
+    return joined_query_segs
 
 
 def run_query(
@@ -67,3 +70,22 @@ def run_query(
         raise Exception('query "{}" found no data, please alter'.format(query))
 
     return _load_pct(df)
+
+
+def handle_predefined(data_id, df=None):
+    import dtale.predefined_filters as predefined_filters
+
+    df = global_state.get_data(data_id) if df is None else df
+    filters = predefined_filters.get_filters()
+    if not filters:
+        return df
+
+    curr_settings = global_state.get_settings(data_id) or {}
+    filter_values = curr_settings.get("predefinedFilters")
+    if not filter_values:
+        return df
+
+    for f in filters:
+        if f.name in filter_values:
+            df = f.handler(df, filter_values[f.name])
+    return df
